@@ -1,7 +1,7 @@
 from numpy import prod
 
 
-def L(obj, I=None):
+def L(self, I=None):
     """Return the L products of acidity constants.
 
     Args:
@@ -12,16 +12,16 @@ def L(obj, I=None):
     ionic strength will be used. Otherwise, the ionic strength is assumed to be
     0.
 
-    L is used by Solution objects to calculate equilibrium pH.
+    L is used by Solution selfects to calculate equilibrium pH.
     """
     if I is None:
-        if obj._I:
-            I = obj._I
+        if self._I:
+            I = self._I
         else:
             I = 0.0
 
-    Ka = obj.Ka_eff(I)
-    index_0 = obj.z0.index(0)
+    Ka = self.Ka_eff(I)
+    index_0 = self.z0.index(0)
     Ka.insert(index_0, 1)
 
     L = [prod(Ka[i:index_0]) for i in range(len(Ka)) if i < index_0] +\
