@@ -1,4 +1,4 @@
-def conductivity(obj):
+def conductivity(self):
     """Return the electrical conductivity of the solution.
 
     Relies on molar conductivity calculations from ion and total conductivity
@@ -7,9 +7,9 @@ def conductivity(obj):
     The conductivity is returned in Seimens per meter.
     """
     con = 0
-    for c, i in zip(obj.concentrations, obj.ions):
+    for c, i in zip(self.concentrations, self.ions):
         con += c * i.molar_conductivity()
 
-    con += obj.OH_conductivity()    # Add OH- contribution.
-    con += obj.H_conductivity()     # Add H+ contribution.
+    con += self.OH_conductivity()    # Add OH- contribution.
+    con += self.H_conductivity()     # Add H+ contribution.
     return con
